// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2019, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

pub static STOPWORDS_ZUL: &[&str] = &[
    "futhi",
    "kahle",
    "kakhulu",
    "kanye",
    "khona",
    "kodwa",
    "kungani",
    "kusho",
    "la",
    "lakhe",
    "lapho",
    "mina",
    "ngesikhathi",
    "nje",
    "phansi",
    "phezulu",
    "u",
    "ukuba",
    "ukuthi",
    "ukuze",
    "uma",
    "wahamba",
    "wakhe",
    "wami",
    "wase",
    "wathi",
    "yakhe",
    "zakhe",
    "zonke",
];
