// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2022, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

pub static STOPWORDS_TGL: &[&str] = &[
    "akin",
    "aking",
    "ako",
    "alin",
    "am",
    "amin",
    "aming",
    "ang",
    "ano",
    "anumang",
    "apat",
    "at",
    "atin",
    "ating",
    "ay",
    "bababa",
    "bago",
    "bakit",
    "bawat",
    "bilang",
    "dahil",
    "dalawa",
    "dapat",
    "din",
    "dito",
    "doon",
    "gagawin",
    "gayunman",
    "ginagawa",
    "ginawa",
    "ginawang",
    "gumawa",
    "gusto",
    "habang",
    "hanggang",
    "hindi",
    "huwag",
    "iba",
    "ibaba",
    "ibabaw",
    "ibig",
    "ikaw",
    "ilagay",
    "ilalim",
    "ilan",
    "inyong",
    "isa",
    "isang",
    "itaas",
    "ito",
    "iyo",
    "iyon",
    "iyong",
    "ka",
    "kahit",
    "kailangan",
    "kailanman",
    "kami",
    "kanila",
    "kanilang",
    "kanino",
    "kanya",
    "kanyang",
    "kapag",
    "kapwa",
    "karamihan",
    "katiyakan",
    "katulad",
    "kaya",
    "kaysa",
    "ko",
    "kong",
    "kulang",
    "kumuha",
    "kung",
    "laban",
    "lahat",
    "lamang",
    "likod",
    "lima",
    "maaari",
    "maaaring",
    "maging",
    "mahusay",
    "makita",
    "marami",
    "marapat",
    "masyado",
    "may",
    "mayroon",
    "mga",
    "minsan",
    "mismo",
    "mula",
    "muli",
    "na",
    "nabanggit",
    "naging",
    "nagkaroon",
    "nais",
    "nakita",
    "namin",
    "napaka",
    "narito",
    "nasaan",
    "ng",
    "ngayon",
    "ni",
    "nila",
    "nilang",
    "nito",
    "niya",
    "niyang",
    "noon",
    "o",
    "pa",
    "paano",
    "pababa",
    "paggawa",
    "pagitan",
    "pagkakaroon",
    "pagkatapos",
    "palabas",
    "pamamagitan",
    "panahon",
    "pangalawa",
    "para",
    "paraan",
    "pareho",
    "pataas",
    "pero",
    "pumunta",
    "pumupunta",
    "sa",
    "saan",
    "sabi",
    "sabihin",
    "sarili",
    "sila",
    "sino",
    "siya",
    "tatlo",
    "tayo",
    "tulad",
    "tungkol",
    "una",
    "walang",
];
