// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2019, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

pub static STOPWORDS_SRP: &[&str] = &[
    "a",
    "avaj",
    "ako",
    "al",
    "ali",
    "arh",
    "au",
    "ah",
    "aha",
    "aj",
    "bar",
    "bi",
    "bila",
    "bili",
    "bilo",
    "bismo",
    "biste",
    "bih",
    "bijasmo",
    "bijaste",
    "bijah",
    "bijahu",
    "bijaše",
    "biće",
    "blizu",
    "broj",
    "brr",
    "bude",
    "budimo",
    "budite",
    "budu",
    "budući",
    "bum",
    "buć",
    "vam",
    "vama",
    "vas",
    "vaša",
    "vaše",
    "vašim",
    "vašima",
    "valjda",
    "veoma",
    "verovatno",
    "već",
    "većina",
    "vi",
    "video",
    "više",
    "vrlo",
    "vrh",
    "ga",
    "gde",
    "gic",
    "god",
    "gore",
    "gđekoje",
    "da",
    "dakle",
    "dana",
    "danas",
    "daj",
    "dva",
    "de",
    "deder",
    "delimice",
    "delimično",
    "dem",
    "do",
    "dobar",
    "dobiti",
    "dovečer",
    "dokle",
    "dole",
    "donekle",
    "dosad",
    "doskoro",
    "dotad",
    "dotle",
    "došao",
    "doći",
    "drugamo",
    "drugde",
    "drugi",
    "e",
    "evo",
    "eno",
    "eto",
    "eh",
    "ehe",
    "ej",
    "želela",
    "želele",
    "želeli",
    "želelo",
    "želeh",
    "želeći",
    "želi",
    "za",
    "zaista",
    "zar",
    "zatim",
    "zato",
    "zahvaliti",
    "zašto",
    "zbilja",
    "zimus",
    "znati",
    "zum",
    "i",
    "ide",
    "iz",
    "izvan",
    "izvoli",
    "između",
    "iznad",
    "ikada",
    "ikakav",
    "ikakva",
    "ikakve",
    "ikakvi",
    "ikakvim",
    "ikakvima",
    "ikakvih",
    "ikakvo",
    "ikakvog",
    "ikakvoga",
    "ikakvom",
    "ikakvome",
    "ikakvoj",
    "ili",
    "im",
    "ima",
    "imam",
    "imao",
    "ispod",
    "ih",
    "iju",
    "ići",
    "kad",
    "kada",
    "koga",
    "kojekakav",
    "kojima",
    "koju",
    "krišom",
    "lani",
    "li",
    "mali",
    "manji",
    "me",
    "mene",
    "meni",
    "mi",
    "mimo",
    "misli",
    "mnogo",
    "mogu",
    "mora",
    "morao",
    "moj",
    "moja",
    "moje",
    "moji",
    "moju",
    "moći",
    "mu",
    "na",
    "nad",
    "nakon",
    "nam",
    "nama",
    "nas",
    "naša",
    "naše",
    "našeg",
    "naši",
    "naći",
    "ne",
    "negde",
    "neka",
    "nekad",
    "neke",
    "nekog",
    "neku",
    "nema",
    "nemam",
    "neko",
    "neće",
    "nećemo",
    "nećete",
    "nećeš",
    "neću",
    "ni",
    "nikada",
    "nikoga",
    "nikoje",
    "nikoji",
    "nikoju",
    "nisam",
    "nisi",
    "niste",
    "nisu",
    "ništa",
    "nijedan",
    "no",
    "o",
    "ova",
    "ovako",
    "ovamo",
    "ovaj",
    "ovde",
    "ove",
    "ovim",
    "ovima",
    "ovo",
    "ovoj",
    "od",
    "odmah",
    "oko",
    "okolo",
    "on",
    "onaj",
    "one",
    "onim",
    "onima",
    "onom",
    "onoj",
    "onu",
    "osim",
    "ostali",
    "otišao",
    "pa",
    "pak",
    "pitati",
    "po",
    "povodom",
    "pod",
    "podalje",
    "poželjan",
    "poželjna",
    "poizdalje",
    "poimence",
    "ponekad",
    "popreko",
    "pored",
    "posle",
    "potaman",
    "potrbuške",
    "pouzdano",
    "početak",
    "pojedini",
    "praviti",
    "prvi",
    "preko",
    "prema",
    "prije",
    "put",
    "pljus",
    "radije",
    "s",
    "sa",
    "sav",
    "sada",
    "sam",
    "samo",
    "sasvim",
    "sva",
    "svaki",
    "svi",
    "svim",
    "svog",
    "svom",
    "svoj",
    "svoja",
    "svoje",
    "svoju",
    "svu",
    "svugde",
    "se",
    "sebe",
    "sebi",
    "si",
    "smeti",
    "smo",
    "stvar",
    "stvarno",
    "ste",
    "su",
    "sutra",
    "ta",
    "tačno",
    "tako",
    "takođe",
    "tamo",
    "tvoj",
    "tvoja",
    "tvoje",
    "tvoji",
    "tvoju",
    "te",
    "tebe",
    "tebi",
    "ti",
    "tima",
    "to",
    "tome",
    "toj",
    "tu",
    "u",
    "uvek",
    "uvijek",
    "uz",
    "uza",
    "uzalud",
    "uzduž",
    "uzeti",
    "umalo",
    "unutra",
    "upotrebiti",
    "uprkos",
    "učinio",
    "učiniti",
    "halo",
    "hvala",
    "hej",
    "hm",
    "hop",
    "hoće",
    "hoćemo",
    "hoćete",
    "hoćeš",
    "hoću",
    "htedoste",
    "htedoh",
    "htedoše",
    "htela",
    "htele",
    "hteli",
    "hteo",
    "htejasmo",
    "htejaste",
    "htejahu",
    "hura",
    "često",
    "čijem",
    "čiji",
    "čijim",
    "čijima",
    "šic",
    "štagod",
    "što",
    "štogod",
    "ja",
    "je",
    "jedan",
    "jedini",
    "jedna",
    "jedne",
    "jedni",
    "jedno",
    "jednom",
    "jer",
    "jesam",
    "jesi",
    "jesmo",
    "jesu",
    "jim",
    "joj",
    "ju",
    "juče",
    "njegova",
    "njegovo",
    "njezin",
    "njezina",
    "njezino",
    "njemu",
    "njen",
    "njim",
    "njima",
    "njihova",
    "njihovo",
    "njoj",
    "nju",
    "će",
    "ćemo",
    "ćete",
    "ćeš",
    "ću",
];
