// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2019, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

pub static STOPWORDS_HEB: &[&str] = &[
    "אבל",
    "או",
    "אולי",
    "אותה",
    "אותו",
    "אותי",
    "אותך",
    "אותם",
    "אותן",
    "אותנו",
    "אז",
    "אחר",
    "אחרות",
    "אחרי",
    "אחריכן",
    "אחרים",
    "אחרת",
    "אי",
    "איזה",
    "איך",
    "אין",
    "איפה",
    "איתה",
    "איתו",
    "איתי",
    "איתך",
    "איתכם",
    "איתכן",
    "איתם",
    "איתן",
    "איתנו",
    "אך",
    "אל",
    "אלה",
    "אלו",
    "אם",
    "אנחנו",
    "אני",
    "אס",
    "אף",
    "אצל",
    "אשר",
    "את",
    "אתה",
    "אתכם",
    "אתכן",
    "אתם",
    "אתן",
    "באיזומידה",
    "באמצע",
    "באמצעות",
    "בגלל",
    "בין",
    "בלי",
    "במידה",
    "במקוםשבו",
    "ברם",
    "בשביל",
    "בשעהש",
    "בתוך",
    "גם",
    "דרך",
    "הוא",
    "היא",
    "היה",
    "היכן",
    "היתה",
    "היתי",
    "הם",
    "הן",
    "הנה",
    "הסיבהשבגללה",
    "הרי",
    "ואילו",
    "ואת",
    "זאת",
    "זה",
    "זות",
    "יהיה",
    "יוכל",
    "יוכלו",
    "יותרמדי",
    "יכול",
    "יכולה",
    "יכולות",
    "יכולים",
    "יכל",
    "יכלה",
    "יכלו",
    "יש",
    "כאן",
    "כאשר",
    "כולם",
    "כולן",
    "כזה",
    "כי",
    "כיצד",
    "כך",
    "ככה",
    "כל",
    "כלל",
    "כמו",
    "כן",
    "כפי",
    "כש",
    "לא",
    "לאו",
    "לאיזותכלית",
    "לאן",
    "לבין",
    "לה",
    "להיות",
    "להם",
    "להן",
    "לו",
    "לי",
    "לכם",
    "לכן",
    "למה",
    "למטה",
    "למעלה",
    "למקוםשבו",
    "למרות",
    "לנו",
    "לעבר",
    "לעיכן",
    "לפיכך",
    "לפני",
    "מאד",
    "מאחורי",
    "מאיזוסיבה",
    "מאין",
    "מאיפה",
    "מבלי",
    "מבעד",
    "מדוע",
    "מה",
    "מהיכן",
    "מול",
    "מחוץ",
    "מי",
    "מכאן",
    "מכיוון",
    "מלבד",
    "מן",
    "מנין",
    "מסוגל",
    "מעט",
    "מעטים",
    "מעל",
    "מצד",
    "מקוםבו",
    "מתחת",
    "מתי",
    "נגד",
    "נגר",
    "נו",
    "עד",
    "עז",
    "על",
    "עלי",
    "עליה",
    "עליהם",
    "עליהן",
    "עליו",
    "עליך",
    "עליכם",
    "עלינו",
    "עם",
    "עצמה",
    "עצמהם",
    "עצמהן",
    "עצמו",
    "עצמי",
    "עצמם",
    "עצמן",
    "עצמנו",
    "פה",
    "רק",
    "שוב",
    "של",
    "שלה",
    "שלהם",
    "שלהן",
    "שלו",
    "שלי",
    "שלך",
    "שלכה",
    "שלכם",
    "שלכן",
    "שלנו",
    "שם",
    "תהיה",
    "תחת",
];
