// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2019, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

pub static STOPWORDS_AZE: &[&str] = &[
    "a",
    "ad",
    "altı",
    "altmış",
    "amma",
    "arasında",
    "artıq",
    "ay",
    "az",
    "bax",
    "belə",
    "bəli",
    "bəlkə",
    "beş",
    "bəy",
    "bəzən",
    "bəzi",
    "bilər",
    "bir",
    "biraz",
    "biri",
    "birşey",
    "biz",
    "bizim",
    "bizlər",
    "bu",
    "buna",
    "bundan",
    "bunların",
    "bunu",
    "bunun",
    "buradan",
    "bütün",
    "ci",
    "cı",
    "çox",
    "cu",
    "cü",
    "çünki",
    "da",
    "daha",
    "də",
    "dedi",
    "dək",
    "dən",
    "dəqiqə",
    "deyil",
    "dir",
    "doqquz",
    "doqsan",
    "dörd",
    "düz",
    "ə",
    "edən",
    "edir",
    "əgər",
    "əlbəttə",
    "elə",
    "əlli",
    "ən",
    "əslində",
    "et",
    "etdi",
    "etmə",
    "etmək",
    "faiz",
    "gilə",
    "görə",
    "ha",
    "haqqında",
    "harada",
    "hə",
    "heç",
    "həm",
    "həmin",
    "həmişə",
    "hər",
    "ı",
    "idi",
    "iki",
    "il",
    "ildə",
    "ilə",
    "ilk",
    "in",
    "indi",
    "isə",
    "istifadə",
    "iyirmi",
    "ki",
    "kim",
    "kimə",
    "kimi",
    "lakin",
    "lap",
    "məhz",
    "mən",
    "mənə",
    "mirşey",
    "nə",
    "nəhayət",
    "niyə",
    "o",
    "obirisi",
    "of",
    "olan",
    "olar",
    "olaraq",
    "oldu",
    "olduğu",
    "olmadı",
    "olmaz",
    "olmuşdur",
    "olsun",
    "olur",
    "on",
    "ona",
    "ondan",
    "onlar",
    "onlardan",
    "onların ",
    "onsuzda",
    "onu",
    "onun",
    "oradan",
    "otuz",
    "öz",
    "özü",
    "qarşı",
    "qədər",
    "qırx",
    "saat",
    "sadəcə",
    "saniyə",
    "səhv",
    "səkkiz",
    "səksən",
    "sən",
    "sənə",
    "sənin",
    "siz",
    "sizin",
    "sizlər",
    "sonra",
    "təəssüf",
    "ü",
    "üç",
    "üçün",
    "var",
    "və",
    "xan",
    "xanım",
    "xeyr",
    "ya",
    "yalnız",
    "yaxşı",
    "yeddi",
    "yenə",
    "yəni",
    "yetmiş",
    "yox",
    "yoxdur",
    "yoxsa",
    "yüz",
    "zaman",
];
