// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2019, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

// Notice: we do not have stopwords for this language yet.
pub static STOPWORDS_TEL: &[&str] = &[];
