// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2019, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

pub static STOPWORDS_UKR: &[&str] = &[
    "але",
    "ви",
    "вона",
    "вони",
    "воно",
    "він",
    "в╡д",
    "з",
    "й",
    "коли",
    "ми",
    "нам",
    "про",
    "та",
    "ти",
    "хоча",
    "це",
    "цей",
    "чи",
    "чого",
    "що",
    "як",
    "яко╞",
    "із",
    "інших",
    "╙",
    "╞х",
    "╡",
];
