// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2019, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

pub static STOPWORDS_POL: &[&str] = &[
    "a",
    "aby",
    "ach",
    "acz",
    "aczkolwiek",
    "aj",
    "albo",
    "ale",
    "ależ",
    "ani",
    "aż",
    "bardziej",
    "bardzo",
    "bez",
    "bo",
    "bowiem",
    "by",
    "byli",
    "bym",
    "bynajmniej",
    "być",
    "był",
    "była",
    "było",
    "były",
    "będzie",
    "będą",
    "cali",
    "cała",
    "cały",
    "chce",
    "choć",
    "ci",
    "ciebie",
    "cię",
    "co",
    "cokolwiek",
    "coraz",
    "coś",
    "czasami",
    "czasem",
    "czemu",
    "czy",
    "czyli",
    "często",
    "daleko",
    "dla",
    "dlaczego",
    "dlatego",
    "do",
    "dobrze",
    "dokąd",
    "dość",
    "dr",
    "dużo",
    "dwa",
    "dwaj",
    "dwie",
    "dwoje",
    "dzisiaj",
    "dziś",
    "gdy",
    "gdyby",
    "gdyż",
    "gdzie",
    "gdziekolwiek",
    "gdzieś",
    "go",
    "godz",
    "hab",
    "i",
    "ich",
    "ii",
    "iii",
    "ile",
    "im",
    "inna",
    "inne",
    "inny",
    "innych",
    "inż",
    "iv",
    "ix",
    "iż",
    "ja",
    "jak",
    "jakaś",
    "jakby",
    "jaki",
    "jakichś",
    "jakie",
    "jakiś",
    "jakiż",
    "jakkolwiek",
    "jako",
    "jakoś",
    "je",
    "jeden",
    "jedna",
    "jednak",
    "jednakże",
    "jedno",
    "jednym",
    "jedynie",
    "jego",
    "jej",
    "jemu",
    "jest",
    "jestem",
    "jeszcze",
    "jeśli",
    "jeżeli",
    "już",
    "ją",
    "każdy",
    "kiedy",
    "kierunku",
    "kilka",
    "kilku",
    "kimś",
    "kto",
    "ktokolwiek",
    "ktoś",
    "która",
    "które",
    "którego",
    "której",
    "który",
    "których",
    "którym",
    "którzy",
    "ku",
    "lat",
    "lecz",
    "lub",
    "ma",
    "mają",
    "mam",
    "mamy",
    "mało",
    "mgr",
    "mi",
    "miał",
    "mimo",
    "między",
    "mnie",
    "mną",
    "mogą",
    "moi",
    "moim",
    "moja",
    "moje",
    "może",
    "możliwe",
    "można",
    "mu",
    "musi",
    "my",
    "mój",
    "na",
    "nad",
    "nam",
    "nami",
    "nas",
    "nasi",
    "nasz",
    "nasza",
    "nasze",
    "naszego",
    "naszych",
    "natomiast",
    "natychmiast",
    "nawet",
    "nic",
    "nich",
    "nie",
    "niech",
    "niego",
    "niej",
    "niemu",
    "nigdy",
    "nim",
    "nimi",
    "nią",
    "niż",
    "no",
    "nowe",
    "np",
    "nr",
    "o",
    "o.o.",
    "obok",
    "od",
    "ok",
    "około",
    "on",
    "ona",
    "one",
    "oni",
    "ono",
    "oraz",
    "oto",
    "owszem",
    "pan",
    "pana",
    "pani",
    "pl",
    "po",
    "pod",
    "podczas",
    "pomimo",
    "ponad",
    "ponieważ",
    "powinien",
    "powinna",
    "powinni",
    "powinno",
    "poza",
    "prawie",
    "prof",
    "przecież",
    "przed",
    "przede",
    "przedtem",
    "przez",
    "przy",
    "raz",
    "razie",
    "roku",
    "również",
    "sam",
    "sama",
    "się",
    "skąd",
    "sobie",
    "sobą",
    "sposób",
    "swoje",
    "są",
    "ta",
    "tak",
    "taka",
    "taki",
    "takich",
    "takie",
    "także",
    "tam",
    "te",
    "tego",
    "tej",
    "tel",
    "temu",
    "ten",
    "teraz",
    "też",
    "to",
    "tobie",
    "tobą",
    "toteż",
    "trzeba",
    "tu",
    "tutaj",
    "twoi",
    "twoim",
    "twoja",
    "twoje",
    "twym",
    "twój",
    "ty",
    "tych",
    "tylko",
    "tym",
    "tys",
    "tzw",
    "tę",
    "u",
    "ul",
    "vi",
    "vii",
    "viii",
    "vol",
    "w",
    "wam",
    "wami",
    "was",
    "wasi",
    "wasz",
    "wasza",
    "wasze",
    "we",
    "według",
    "wie",
    "wiele",
    "wielu",
    "więc",
    "więcej",
    "wszyscy",
    "wszystkich",
    "wszystkie",
    "wszystkim",
    "wszystko",
    "wtedy",
    "www",
    "wy",
    "właśnie",
    "wśród",
    "xi",
    "xii",
    "xiii",
    "xiv",
    "xv",
    "z",
    "za",
    "zapewne",
    "zawsze",
    "zaś",
    "ze",
    "zeznowu",
    "znowu",
    "znów",
    "został",
    "zł",
    "żaden",
    "żadna",
    "żadne",
    "żadnych",
    "że",
    "żeby",
];
