// Sonic
//
// Fast, lightweight and schema-less search backend
// Copyright: 2022, Valerian Saliou <valerian@valeriansaliou.name>
// License: Mozilla Public License v2.0 (MPL v2.0)

pub static STOPWORDS_HYE: &[&str] = &[
    "այդ",
    "այլ",
    "այն",
    "այս",
    "դու",
    "դուք",
    "եմ",
    "են",
    "ենք",
    "ես",
    "եք",
    "է",
    "էի",
    "էին",
    "էինք",
    "էիր",
    "էիք",
    "էր",
    "ըստ",
    "թ",
    "ի",
    "ին",
    "իսկ",
    "իր",
    "կամ",
    "համար",
    "հետ",
    "հետո",
    "մենք",
    "մեջ",
    "մի",
    "ն",
    "նա",
    "նաև",
    "նրա",
    "նրանք",
    "որ",
    "որը",
    "որոնք",
    "որպես",
    "ու",
    "ում",
    "պիտի",
    "վրա",
    "և",
];
